@@ -567,6 +567,19 @@ Change amixer master volume by AMOUNT.
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-volume-amixer" '("emms-volume-amixer-c")))
 
+;;;***
+
+;;;### (autoloads nil "emms-volume-mixerctl" "emms-volume-mixerctl.el"
+;;;;;;  (0 0 0 0))
+;;; Generated autoloads from emms-volume-mixerctl.el
+
+(autoload 'emms-volume-mixerctl-change "emms-volume-mixerctl" "\
+Change mixerctl master volume by AMOUNT.
+
+\(fn AMOUNT)" nil nil)
+
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-volume-mixerctl" '("emms-volume-mixerctl-c")))
+
 ;;;***
 
 ;;;### (autoloads nil "emms-volume-pulse" "emms-volume-pulse.el"
